from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, String, Array, Directory, Boolean, Int, Float

Chicsignificantinteractions_V0_1_0 = CommandToolBuilder(tool="chicSignificantInteractions", base_command=["chicSignificantInteractions"], inputs=[ToolInput(tag="in_background_model_file", input_type=File(optional=True), prefix="--backgroundModelFile", doc=InputDocumentation(doc="path to the background file which is necessary to\ncompute the rbz-score")), ToolInput(tag="in_x_fold_background", input_type=String(optional=True), prefix="--xFoldBackground", doc=InputDocumentation(doc="Filter x-fold over background. Used to merge\nneighboring bins with a broader peak but less\nsignificant interactions to a single peak with high\nsignificance. Used only for pValue option.")), ToolInput(tag="in_loose_p_value", input_type=String(optional=True), prefix="--loosePValue", doc=InputDocumentation(doc="loose p-value threshold to filter target regions in a\nfirst round. Used to merge neighboring bins with a\nbroader peak but less significant interactions to a\nsingle peak with high significance. Used only for\npValue option.")), ToolInput(tag="in_interaction_file", input_type=Array(t=File(), optional=True), prefix="--interactionFile", doc=InputDocumentation(doc="path to the interaction files which should be used for\naggregation of the statistics.")), ToolInput(tag="in_p_value", input_type=String(optional=True), prefix="--pValue", doc=InputDocumentation(doc="p-value threshold to filter target regions for\ninclusion in differential analysis.")), ToolInput(tag="in_out_filename_suffix", input_type=File(optional=True), prefix="--outFileNameSuffix", doc=InputDocumentation(doc="File name suffix to save the results; prefix is the\ninput file name.")), ToolInput(tag="in_interaction_file_folder", input_type=File(optional=True), prefix="--interactionFileFolder", doc=InputDocumentation(doc="Folder where the interaction files are stored. Applies\nonly for batch mode.")), ToolInput(tag="in_target_folder", input_type=Directory(optional=True), prefix="--targetFolder", doc=InputDocumentation(doc="Folder where the target files are stored.")), ToolInput(tag="in_output_folder", input_type=Directory(optional=True), prefix="--outputFolder", doc=InputDocumentation(doc="Output folder of the significant interaction files.")), ToolInput(tag="in_write_filenames_to_file", input_type=File(optional=True), prefix="--writeFileNamesToFile", doc=InputDocumentation(doc="The file to store the target file names.")), ToolInput(tag="in_batch_mode", input_type=Boolean(optional=True), prefix="--batchMode", doc=InputDocumentation(doc="Turn on batch mode. The given file for")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="--threads", doc=InputDocumentation(doc="Number of threads (uses the python multiprocessing\nmodule).")), ToolInput(tag="in_truncate_zerop_values", input_type=Boolean(optional=True), prefix="--truncateZeroPvalues", doc=InputDocumentation(doc="Sets all p-values which are equal to zero to one. This\nhas the effect that the associated positions are not\npart of the significance decision.")), ToolInput(tag="in_fixate_range", input_type=Int(optional=True), prefix="--fixateRange", doc=InputDocumentation(doc="Fixate range of backgroundmodel starting at distance\nx. E.g. all values greater than 500kb are set to the\nvalue of the 500kb bin.")), ToolInput(tag="in_peak_interactions_threshold", input_type=Int(optional=True), prefix="--peakInteractionsThreshold", doc=InputDocumentation(doc="The minimum number of interactions a detected peak\nneeds to have to be considered.")), ToolInput(tag="in_resolution", input_type=Int(optional=True), prefix="--resolution", doc=InputDocumentation(doc="Resolution of the bin in genomic units. Values are set\nas number of bases, e.g. 1000 for a 1kb, 5000 for a\n5kb or 10000 for a 10kb resolution.This value is used\nto merge neighboring bins.")), ToolInput(tag="in_compute_sample_number", input_type=Int(optional=True), prefix="--computeSampleNumber", doc=InputDocumentation(doc="Number of samples to compute together. Applies only in\nbatch mode.")), ToolInput(tag="in_multiple_testing", input_type=String(optional=True), prefix="--multipleTesting", doc=InputDocumentation(doc="Multiple testing correction per relative distance with\nBonferroni or FDR.")), ToolInput(tag="in_threshold_multiple_testing", input_type=Float(optional=True), prefix="--thresholdMultipleTesting", doc=InputDocumentation(doc="Threshold for Bonferroni / FDR. Either a float value\nfor all or a file with one threshold per relative\ndistance."))], outputs=[ToolOutput(tag="out_out_filename_suffix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_filename_suffix", type_hint=File()), doc=OutputDocumentation(doc="File name suffix to save the results; prefix is the\ninput file name.")), ToolOutput(tag="out_output_folder", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_output_folder", type_hint=File()), doc=OutputDocumentation(doc="Output folder of the significant interaction files."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Chicsignificantinteractions_V0_1_0().translate("wdl", allow_empty_container=True)

